# Dlmr Tools
    
[![PyPI version](https://badge.fury.io/py/dlmr-tools.svg)](https://badge.fury.io/py/dlmr-tools)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

1. [🔧 Usage](#-usage)
2. [📦 Installation](#-installation)
3. [⚖️ License](#️-license)
4. [🔄 Changelog](#-changelog)

## 🔧 Usage

Composed of a set of tools to help you perform some tasks in your project:

1. [Data Tool](#-data-tool)
2. [Graph Tool](#-graph-tool)

### 📚 Data Tool

#### 🔧 Usage

You can use the `Data Tool` to import data from `.xlsx` files.

#### ✏️ Example

```python

```

### 📊 Graph Tool 

#### 🔧 Usage

You can use the `Graph Tool` to create graphs from data.

#### ✏️ Example

```python

```

## 📦 Installation

```bash
pip install dlmr_tools
```

## ⚖️ License

This project is licensed under the MIT License - see the [LICENSE](LICENSE.md) file for details.

## 🔄 Changelog

Check the [CHANGELOG](CHANGELOG.md) file for details.